Documentation
¶
Overview ¶
Package config manages fuzzing configs for cobra-cli commands.
This package provides the ability to set a default fuzzing config that gets used by the fuzzing commands.
It additionally simplifies reading in bug reports.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetConfigForTarget ¶
GetConfigForTarget returns the fuzzing config associated with a given fuzzing target
func SetDefaultConfig ¶
SetDefaultConfig can be used to set the default fuzzing config to be used by the cobra-cli commands
Types ¶
type BugReport ¶
type BugReport struct {
Strategy strategy.Strategy `yaml:"-"`
Target string `yaml:"target"`
StrategyNum strategy.FuzzingStrategy `yaml:"strategy"`
TimeFound string `yaml:"time_found"`
OffendingCommit string `yaml:"offending_commit"`
ByteStringAsString string `yaml:"byte_string"`
Query []string `yaml:"query"`
ByteString []byte
}
BugReport represents a bug report parsed from a generated .yml file by the fuzzer
func ReadBugreport ¶
ReadBugreport reads in the bugreport pointed to by the given path
Click to show internal directories.
Click to hide internal directories.