Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterMiddleware ¶
func RegisterMiddleware(m Middleware, conf *scheduler.Config)
RegisterMiddleware takes in a middleware and registers it by modifying the passed config.
Types ¶
type Hooks ¶
type Hooks struct {
StrategyHooks strategy.StrategyMiddleware
DBHooks dbms.DBMiddleware
}
Hooks holds all possible hooks which are called by the middleware while fuzzing.
type Middleware ¶
type Middleware interface {
// Get the struct of hooks to register
Hooks() Hooks
}
Directories
¶
| Path | Synopsis |
|---|---|
|
Package exporter provides a prometheus exporter for monitoring dinkel.
|
Package exporter provides a prometheus exporter for monitoring dinkel. |
Click to show internal directories.
Click to hide internal directories.