prometheus

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2024 License: MIT Imports: 19 Imported by: 0

Documentation

Overview

Package exporter provides a prometheus exporter for monitoring dinkel.

It provides metrics during fuzzing. These metrics include:

  • query counts
  • statement counts
  • generation latencies
  • query latencies
  • count of query result types

Additionally, there is the possibility of exposing "full" metrics, which are useful for benchmarking the fuzzer itself. In full mode, in addition to the previous metrics, the fuzzer exposes the following data:

  • total size of all queries
  • total count of all keywords in all queries
  • query context data dependency count in all queries
  • AGS data dependency count in all queries

These metrics are exposed on the port passed to RegisterExporter on the /metrics endpoint.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RegisterExporter

func RegisterExporter(port int, conf *scheduler.Config, useFullExporter bool)

RegisterExporter registers a new prometheus exporter for dinkel and exposes its metrics on the passed port.

It returns a scheduler.Config, where relevant fields are wrapped with middleware for collecting metrics.

Types

This section is empty.

Jump to