clauses

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ExistingLabel

type ExistingLabel struct {
	LabelType schema.StructuralType
	// contains filtered or unexported fields
}

ExistingLabel drop-in for apache age

func (*ExistingLabel) Generate

func (c *ExistingLabel) Generate(seed *seed.Seed, s *schema.Schema) []translator.Clause

Generate the ExistingLabel subclauses. Different from the OpenCypher implementation, this drop-in never randomly chooses a label for a different structuralType than specified in its LabelType.

func (ExistingLabel) TemplateString

func (c ExistingLabel) TemplateString() string

TemplateString returns either the chosen name or a format string for a new label

type Merge

type Merge struct {
	// contains filtered or unexported fields
}

Merge drop-in for apache age

func (*Merge) Generate

func (c *Merge) Generate(seed *seed.Seed, s *schema.Schema) []translator.Clause

Generate the merge subclauses. Different from the OpenCypher implementation, this drop-in doesn't have a CreateElementChain as its subclause, instead just a single CreateElement.

func (Merge) ModifySchema

func (c Merge) ModifySchema(s *schema.Schema)

ModifySchema after drop-in generation

func (Merge) TemplateString

func (c Merge) TemplateString() string

TemplateString for the merge drop-in

Jump to