opencypher

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2024 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package opencypher provides the OpenCypher model from which all other models descend.

This model is the only model without an implementation or driver. All other models essentially extend the OpenCypher model by modifying its clauses, generation config.Config and schema.OpenCypherSchema.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type RootClause

type RootClause clauses.ReadClause

RootClause of OpenCypher represents the root of the AST.

func (*RootClause) Generate

func (c *RootClause) Generate(seed *seed.Seed, s *schema.Schema) []translator.Clause

Generate subclauses for OpenCypherRootClause

Directories

Path Synopsis
Package config provides the config for adapt query generation to targets.
Package config provides the config for adapt query generation to targets.
Package schema defines the schema used for complex, stateful query generation.
Package schema defines the schema used for complex, stateful query generation.

Jump to