none

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2024 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type NoStrategyReducible

type NoStrategyReducible interface {
	translator.Clause
	// This function gets called on clauses when reducing a bug report generated on
	// a bug which was found using no strategy.
	//
	// Gets passed the clause capturer that captured the clause.
	NoStrategyReduce(*helperclauses.ClauseCapturer) translator.Clause
}

TODO: There has to be a better place to put this... NoStrategyReducible contains the NoStrategyReduce function.

Clauses may implement this interface to make reduction more precise. Clauses not implementing this interface will get replaced by empty clauses for reduction.

type Strategy

type Strategy struct{}

func (*Strategy) DiscardQuery

func (s *Strategy) DiscardQuery(resultType dbms.QueryResultType, db dbms.DB, dbOpts dbms.DBOptions, res dbms.QueryResult, seed *seed.Seed) bool

func (*Strategy) GetQueryResultType

func (s *Strategy) GetQueryResultType(db dbms.DB, dbOpts dbms.DBOptions, res dbms.QueryResult, errorMessageRegex *dbms.ErrorMessageRegex) dbms.QueryResultType

func (*Strategy) GetRootClause

func (s *Strategy) GetRootClause(impl translator.Implementation, schema *schema.Schema, seed *seed.Seed) translator.Clause

func (*Strategy) PrepareQueryForBugreport

func (s *Strategy) PrepareQueryForBugreport(query []string) []string

func (*Strategy) ReduceStep

Simply removes root clauses one by one

func (Strategy) Reset

func (s Strategy) Reset()

func (*Strategy) ValidateReductionResult

func (s *Strategy) ValidateReductionResult(driver dbms.DB, orig []dbms.QueryResult, new []dbms.QueryResult) bool

Compares the errors produced by the last statements. Uses the driver's IsEqualResult function if implemented, otherwise it just compares the strings of the errors.

func (*Strategy) ValidateRerunResults

func (s *Strategy) ValidateRerunResults([]dbms.QueryResult, dbms.DB) dbms.QueryResultType

ValidateRerunResults always returns valid, as no strategy only checks for errors and crashes

Jump to