Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExistingLabel ¶
type ExistingLabel struct {
LabelType schema.StructuralType
// contains filtered or unexported fields
}
ExistingLabel drop-in for apache age
func (*ExistingLabel) Generate ¶
func (c *ExistingLabel) Generate(seed *seed.Seed, s *schema.Schema) []translator.Clause
Generate the ExistingLabel subclauses. Different from the OpenCypher implementation, this drop-in never randomly chooses a label for a different structuralType than specified in its LabelType.
func (ExistingLabel) TemplateString ¶
func (c ExistingLabel) TemplateString() string
TemplateString returns either the chosen name or a format string for a new label
type Merge ¶
type Merge struct {
// contains filtered or unexported fields
}
Merge drop-in for apache age
func (*Merge) Generate ¶
Generate the merge subclauses. Different from the OpenCypher implementation, this drop-in doesn't have a CreateElementChain as its subclause, instead just a single CreateElement.
func (Merge) ModifySchema ¶
ModifySchema after drop-in generation
func (Merge) TemplateString ¶
TemplateString for the merge drop-in
Click to show internal directories.
Click to hide internal directories.